=======
mscales
=======

.. image:: https://app.travis-ci.com/fabianmoss/mscales.svg?branch=main
        :target: https://app.travis-ci.com/fabianmoss/mscales
        :alt: Travis CI Status

.. image:: https://img.shields.io/pypi/v/mscales.svg
        :target: https://pypi.python.org/pypi/mscales
        :alt: PyPi Status

.. image:: https://readthedocs.org/projects/mscales/badge/?version=latest
        :target: https://mscales.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

Python package to generate and analyze musical scales. 3

* Free software: 3-clause BSD license
* Documentation: https://mscales.readthedocs.io/en/latest/.
* Package build with a `cookiecutter template <https://nsls-ii.github.io/scientific-python-cookiecutter/index.html>`_

Features
--------

* TODO
